@@ -80,7 +80,7 @@ void KODayMatrix::setCalendar(const Akonadi::ETMCalendar::Ptr &calendar)
     mCalendar = calendar;
     mCalendar->registerObserver(this);
 
-    setAcceptDrops(mCalendar != Q_NULLPTR);
+    setAcceptDrops(mCalendar != nullptr);
     updateIncidences();
 }
 
@@ -274,7 +274,7 @@ void KODayMatrix::updateJournals()
 {
     const KCalCore::Incidence::List incidences = mCalendar->incidences();
 
-    foreach (const KCalCore::Incidence::Ptr &inc, incidences) {
+    for (const KCalCore::Incidence::Ptr &inc : incidences) {
         Q_ASSERT(inc);
         QDate d = inc->dtStart().toTimeSpec(mCalendar->timeSpec()).date();
         if (inc->type() == KCalCore::Incidence::TypeJournal &&
@@ -303,7 +303,7 @@ void KODayMatrix::updateTodos()
 {
     const KCalCore::Todo::List incidences = mCalendar->todos();
     QDate d;
-    foreach (const KCalCore::Todo::Ptr &t, incidences) {
+    for (const KCalCore::Todo::Ptr &t : incidences) {
         if (mEvents.count() == NUMDAYS) {
             // No point in wasting cpu, all days are bold already
             break;
@@ -346,10 +346,10 @@ void KODayMatrix::updateEvents()
         // No point in wasting cpu, all days are bold already
         return;
     }
-    KCalCore::Event::List eventlist = mCalendar->events(mDays[0], mDays[NUMDAYS - 1],
+    const KCalCore::Event::List eventlist = mCalendar->events(mDays[0], mDays[NUMDAYS - 1],
                                       mCalendar->timeSpec());
 
-    Q_FOREACH (const KCalCore::Event::Ptr &event, eventlist) {
+    for (const KCalCore::Event::Ptr &event : eventlist) {
         if (mEvents.count() == NUMDAYS) {
             // No point in wasting cpu, all days are bold already
             break;
@@ -674,7 +674,7 @@ void KODayMatrix::dropEvent(QDropEvent *e)
         } else if (keyboardModifiers & Qt::ShiftModifier) {
             action = DRAG_MOVE;
         } else {
-            QAction *copy = Q_NULLPTR, *move = Q_NULLPTR;
+            QAction *copy = nullptr, *move = nullptr;
             QMenu *menu = new QMenu(this);
             if (exist) {
                 move = menu->addAction(QIcon::fromTheme(QStringLiteral("edit-paste")), i18n("&Move"));
